# the house

A text-based game written in python

## Install or Download

You can install the game with pip by typing `pip install thehouse`

or you can download this repository

## Play

If you have installed **thehouse** via pip you can call the game and run it by typing `thehouse`.

If you downloaded the repository, on the root of the repo run `poetry run python -m thehouse` and the game will start!
